package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````H)H``#0```"LUP```@0`!30`(``(
M`"@`'``;``$``'#8TP``V%,!`-A3`0`(````"`````0````$````!@```#0`
M```T@```-(`````!`````0``!0````0````#````-`$``#2!```T@0``&0``
M`!D````$`````0````$``````````(````"```#DTP``Y-,```4`````@```
M`0```.33``#DTP$`Y-,!`%@"``"0$@``!@````"````"````\-,``/#3`0#P
MTP$`&`$``!@!```&````!`````0```!0`0``4($``%"!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!`````O;&EB+VQD
M+6QI;G5X+6%R;6AF+G-O+C,`````!````!`````!````1TY5```````"````
M!@```"`````$````%`````,```!'3E4`?TBHURW2Q:JU;8J=\(TI[T7##IMA
M````!0```"`````*````H!(`"`)$$2$``D``5@!P&,((`#`(`!41```0`@`H
M`````````$@"8`H`"@`$A`.H0`A%8&D`A`D^0CR7``$`""18@`0)8`R3>`!`
M6@!``$```0$#"0!`@(S`A```$)`0BPD`"`$0@(%`0,()@"Q`F`)!`"``(`0)
M@)0!I`Z74D`%``````````8````'````"0`````````````````````````*
M````#`````X````0````$0```!(````4````%P`````````9````````````
M```:````'@```"``````````)````"4````F`````````"<````H````*P``
M```````M```````````````N````+P```#`````Q`````````#4````V````
M`````#H``````````````#L````]````/@`````````_````0````$(```!$
M````1P````````!*````2P```$P```!-`````````$X`````````````````
M``````````````````!/````4`````````!2`````````%0```!7````6```
M`````````````````%D```!:````7@````````!@`````````&$`````````
M8P```&0``````````````&8```!G````:````&D```!L````7Y:3'*-:[Y!6
MVY,<PXZ'_PTZEPO2402$@72"#7KP2FM]08[%=E0\E,T_#*_W(\X@B0=PTR!T
ML`+59-1\9J_,9BY./?;;]P!>!J2'_P&O-.BQ2)WGSDJN_\[>1RW@IP(*/_G_
MO.)'Q@$Y0`ROQ@[@/3Y^EGSL/Y`";7.%Q<6)!9!AF.\2`2/YI)V[DQQ"1=7L
MAOF<@7WM$0^ZE9,<6YH[#T%-G7RGW:-K6>^7>3GRBQP,%.*>!#*EA:("]AG;
MS>.>^Z%L8.K3[P[(.4`?,F+;[;F-\0[I^\/""HH05^W>DQRM2^/`V7%8'"O0
MX2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4:+KCDGPA_^0.BIC=PFYZ:?J+V357DZT$
M8C?C\,%#\N_(WX4@3U>DFY;%N9Q`4!M]7S&X@@V^VE<;LP&+;[S02WUV;^-P
MF4+NH6L)0]8A8F0'"P^UI7ZIG)MBT/J"["SVBVM_FGR&\)9\T9\L_.\+4?F0
M=8(-0V9+$`5LLLT\K3D-%^I:\:/@^TE7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%
MF[;>J\J?R=6R<0`````````````````````1```````````````@````+0``
M````````````(````#P``````````````"````!0```````````````@````
M@@,``%"5````````$@```&0"``!8E@```````!(````+`P``1)4````````2
M````[P(``,26````````$@```(,$```LU@$``````"``%P#D`0``D)<`````
M```2````Z`(``*B7````````$@```-0!``"\E0```````!(````/!0``7/,`
M`#@````2``T`[`,``#S6`0``````$``8`)H"```XF````````!(```#-`@``
M!)8````````2````PP0``#C6`0`$````$0`7`#(#```LF````````!(````K
M!0``2.\``)P#```2``T`:`0```CA```<`0``$@`-`(D#``"@E@```````!(`
M``"K`@``:)@````````2````0P,``'25````````$@```/L#``!TY@$`````
M`!``&``/`0``#)<````````2````1@0``%R5````````$@```'0$```XY0``
M$`H``!(`#0"=!```3-X``,0````2``T`80,```"7````````$@```%L$``#@
MX```*````!(`#0"T`@``;)<````````2````V@(``!"6````````$@```(T"
M``#0E@```````!(```"M`0``/)<````````2````'P,``%R8````````$@``
M`)P#``!`U@$`!````"$`&`!,`@``B)8````````2````4P(``!B7````````
M$@```/T"``#<E@```````!(```#9`P``/-8!```````0`!<`G@```.27````
M````$@```.("``!$F````````!(```!:`P``])8````````2````1@(``%"8
M````````$@```&P"``!HE0```````!(```"=`P``0-8!``0````A`!@`!@0`
M`'3F`0``````$``8`#P#``!8U@$`!````!$`&``3!```$/0```0````2``T`
MN`$``!R6````````$@```(8!``"LE@```````!(```"S!```K/,``&0````2
M``T`[P0``%#D``#H````$@`-`!T$```4]````````!(`#@"\`@``[)4`````
M```2````AP0``*":````````$@`-`-P$```DE0```````!(`"P"^````))<`
M```````2`````@$``%36`0`!````$0`8`/8"``#,EP```````!(```".!```
M'/0```0````1``\`X`,``#S6`0``````$``8`&D#``#\EP```````!(```!S
M`P``@)4````````2````:@```'B7````````$@```!P!``"<EP```````!(`
M``#:!```Q-T``#0````2``T`3P$``."5````````$@````X$``!TY@$`````
M`!``&`#B!```%-\``,P!```2``T`TP```)B5````````$@```'L"``#XE0``
M`````!(```"'````()@````````2````,@(``'28````````$@```,8!``#8
MEP```````!(```#A````0)8````````2````\P````B8````````$@```"T!
M``!0U@$`!````!$`&`";`P``0-8!``0````1`!@`>`$``"B6````````$@``
M``0#``!4EP```````!(```#Z`P``=.8!```````0`!@``04``-SC``!<````
M$@`-`*\```#4E0```````!(````J`P``?)8````````2````.`$``,"7````
M````$@```($$```LU@$``````!``%P"Y`P``2-8!``0````1`!@`D@(``/"7
M````````$@```#0$```XY```&````!(`#0`"`@``3)8````````2````[P$`
M`'"6````````$@```)8#``"`F```'`(``!(`#0!4`0``C)4````````2````
M4P,``+"5````````$@```$H#```TE@```````!(````8`P``I)4````````2
M````$@,``,B5````````$@```*("```PEP```````!(```#[`0``E)8`````
M```2````>P,``+27````````$@```,T$```DX@``N`$``!(`#0!9`0``A)<`
M```````2````U`(``$B7````````$@```$\$``#D\@``>````!(`#0!X````
MZ)8````````2````E@$``!28````````$@```",$```0WP``!````!(`#0"?
M`0``9)8````````2````90$``&"7````````$@````!L:6)P97)L+G-O+C4N
M,3@`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?
M`%]*=E]296=I<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%V95]D97-T
M<G5C=&]R7W@`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L
M86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=U-6<'8`
M4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`%!E<FQ?8W)O86M?;65M;W)Y
M7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L
M7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E
M860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R
M<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`7U]R96=I<W1E
M<E]A=&9O<FL`97AI=`!S<')I;G1F`'-T<FYC;7``7U]S=')D=7``8VQO<V5D
M:7(`<W1R;F-P>0!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`
M<W1R<W1R`')M9&ER`&UE;6-P>0!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A
M=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`97AE8W9P`'-T<F-H<@!F<')I
M;G1F`')E861D:7(V-`!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T
M87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%R;6AF+G-O+C,`7U]S=&%C
M:U]C:&M?9W5A<F0`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`
M7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C
M7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE
M`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`
M<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L
M:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-4
M04-+`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0`````````````
M```"``,``@`"``$````"`````0`!``(``@`!``(``0`!``(``@`"``$````"
M``$``0`"``$``@`"``(````"``(``P`#``(``0````(``@`#``,``@`!``(`
M`0```````0`!``$``@`!``$```````(``0`!``(``@```````0````$``0``
M``(````#`````````````@````(``0`!`````@````$`!``"``$```````$`
M`@`"``(``@`"``(``@`"``$````"``$```````$``````````0`!`*4#```0
M````(````!1I:0T```0`004````````!``$`(@(``!`````@````%&EI#0``
M`P!!!0````````$``0!Q`@``$``````````4:6D-```"`$$%````````*-8!
M`!4"``!`U@$`%$\``$C6`0`46```4-8!`!1.``!4U@$`%#L``%C6`0`4,```
M%-4!`!8'```8U0$`%@4``!S5`0`6&@``(-4!`!8M```DU0$`%A<``"C5`0`6
M0```+-4!`!9>```PU0$`%D<``#35`0`680``.-4!`!9?```\U0$`%@P``$#5
M`0`68@``1-4!`!94``!(U0$`%D0``$S5`0`6-P``4-4!`!9(``!4U0$`%A``
M`%C5`0`6(```7-4!`!8R``!@U0$`%E```&35`0`68```:-4!`!9,``!LU0$`
M%EL``'#5`0`6!@``=-4!`!9M``!XU0$`%EP``'S5`0`650``@-4!`!8E``"$
MU0$`%F0``(C5`0`6%0``C-4!`!8S``"0U0$`%@(``)35`0`6"```F-4!`!8A
M``"<U0$`%B<``*#5`0`6:@``I-4!`!8K``"HU0$`%AT``*S5`0`6&0``L-4!
M`!8F``"TU0$`%CH``+C5`0`68P``O-4!`!8B``#`U0$`%F@``,35`0`640``
MR-4!`!9N``#,U0$`%A\``-#5`0`600``U-4!`!9G``#8U0$`%@H``-S5`0`6
M0@``X-4!`!8+``#DU0$`%F4``.C5`0`65@``[-4!`!8\``#PU0$`%DL``/35
M`0`6*0``^-4!`!99``#\U0$`%C\```#6`0`630``!-8!`!9K```(U@$`%DD`
M``S6`0`6$@``$-8!`!8/```4U@$`%BH``!C6`0`6+```'-8!`!8C```@U@$`
M%A8``"36`0`62@``"$`MZ6L!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y<@_`0``
MQH_B$\J,XLC_O.4`QH_B$\J,XL#_O.4`QH_B$\J,XKC_O.4`QH_B$\J,XK#_
MO.4`QH_B$\J,XJC_O.4`QH_B$\J,XJ#_O.4`QH_B$\J,XIC_O.4`QH_B$\J,
MXI#_O.4`QH_B$\J,XHC_O.4`QH_B$\J,XH#_O.4`QH_B$\J,XGC_O.4`QH_B
M$\J,XG#_O.4`QH_B$\J,XFC_O.4`QH_B$\J,XF#_O.4`QH_B$\J,XEC_O.4`
MQH_B$\J,XE#_O.4`QH_B$\J,XDC_O.4`QH_B$\J,XD#_O.4`QH_B$\J,XCC_
MO.4`QH_B$\J,XC#_O.4`QH_B$\J,XBC_O.4`QH_B$\J,XB#_O.4`QH_B$\J,
MXAC_O.4`QH_B$\J,XA#_O.4`QH_B$\J,X@C_O.4`QH_B$\J,X@#_O.4`QH_B
M$\J,XOC^O.4`QH_B$\J,XO#^O.4`QH_B$\J,XNC^O.4`QH_B$\J,XN#^O.4`
MQH_B$\J,XMC^O.4`QH_B$\J,XM#^O.4`QH_B$\J,XLC^O.4`QH_B$\J,XL#^
MO.4`QH_B$\J,XKC^O.4`QH_B$\J,XK#^O.4`QH_B$\J,XJC^O.4`QH_B$\J,
MXJ#^O.4`QH_B$\J,XIC^O.4`QH_B$\J,XI#^O.4`QH_B$\J,XHC^O.4`QH_B
M$\J,XH#^O.4`QH_B$\J,XGC^O.4`QH_B$\J,XG#^O.4`QH_B$\J,XFC^O.4`
MQH_B$\J,XF#^O.4`QH_B$\J,XEC^O.4`QH_B$\J,XE#^O.4`QH_B$\J,XDC^
MO.4`QH_B$\J,XD#^O.4`QH_B$\J,XCC^O.4`QH_B$\J,XC#^O.4`QH_B$\J,
MXBC^O.4`QH_B$\J,XB#^O.4`QH_B$\J,XAC^O.4`QH_B$\J,XA#^O.4`QH_B
M$\J,X@C^O.4`QH_B$\J,X@#^O.4`QH_B$\J,XOC]O.4`QH_B$\J,XO#]O.4`
MQH_B$\J,XNC]O.4`QH_B$\J,XN#]O.4`QH_B$\J,XMC]O.4`QH_B$\J,XM#]
MO.4`QH_B$\J,XLC]O.4`QH_B$\J,XL#]O.4`QH_B$\J,XKC]O.4`QH_B$\J,
MXK#]O.4`QH_B$\J,XJC]O.5P0"WI(-!-XA0`C>40$(WE#""-Y10`C>(0$(WB
M#""-XI#__^O$$9_EQ`&?Y0$@H.&W%@#KO#&?Y0!0T^4``%7CM$&?%0D``!I?
M___KK"&?Y0``4./H#P+E7@``"IA!G^4[___K``"4Y>'__^MM5L#E``"4Y=[_
M_^L`,*#A``"4Y1HDT^4"((+C&B3#Y=C__^L4,)WE46N?[04P@^)1>Y_MD#H$
M[F1;N.X&:S7NQVNT[A#Z\>X:)-#E`2""XQHDP.5#``#*`P&@X4C__^L0$)WE
M+#&?Y10@G>4`0)'E).&?Y1AAG^4$P)/E`0!2XP0PH./T/P;E`%"@X0P!G^40
M0(7H!$!!P@C`A>4,`(7E\%\&Y0)!A,`,P(7"`P``V@3@L>4$`%'A!."LY?O_
M_QH-X8+B`,"@XP#`C>4%,*#AZ`\6Y0,@@N+$$)_E#L&%YV___^NH,)_E`$!0
MX@T```KH#Q;E#?__ZQP0C>*D`)_E2`\`ZXA0G^4``%#C"0``"N@/%N7V_O_K
M6___ZP0`H.$@T(WB<("]Z.@/$^5]___K`$"@X>W__^KL#Q7E``!0XP$```HK
M%@#K\/__ZAP0C>)4`)_E,P\`ZP``4./L#P7EZO__"O;__^I9___K`0"@XQO_
M_^L`````````````@/___\]!8)<``.27``!4U@$`4-8!`%CV`0`TU@$`L/<`
M`+3W``#XW0``8/4``/ST`````*#A`+"@XP#@H.,$$)WD#2"@X00@+>4$`"WE
M$,"?Y03`+>4,`)_E##"?Y?3^_^M<___K$/0``("8``"L\P``%#"?Y10@G^4#
M,(_@`B"3YP``4N,>_R\![_[_ZAPZ`0`@`0``"$`MZ2``G^4@,)_E`S!@X`8`
M4^,(@+V8%#"?Y0``4^,(@+T(,_\OX0B`O>@\U@$`/]8!```````(0"WI*`"?
MY2@PG^4#,&#@0S&@X:,_@^##$+#A"("]"!0@G^4``%+C"("]"#+_+^$(@+WH
M/-8!`#S6`0``````$$`MZ1A`G^4`,-3E``!3XQ"`O1C;___K`3"@XP`PQ.40
M@+WH7-8!`"0`G^4(0"WI`#"0Y0``4^,#```*%#"?Y0``4^,````*,_\OX0A`
MO>C:___J[-,!``````#P#RWI.,"`X@/<3>)X,(#B@&"-XFP`C>4H8(WE2#"-
MY?!'S>$"`9SH_TB@XP``H.,AK*#A"*2*X0%4H.$()*#A6%"-Y5R@C>4P((WE
MV"7-X0!0H.,A9*#A!"`"X`$<H.$%,`/@*+R@X0%`@N$#4*#A-+"-Y?!$S>'0
M0\WA_RB@XP`PH.,"0`3@`U`%X-`DS>$H=*#A"&R&X60`C>4\`(WE`!"@X_\,
MH.,&``#@!Q`!X``@@N$!,(/A_P"@XP`0H.,*``#@"Q`!X&!PC>4`((+A`3"#
MX=`&S>$(C*#A"$"$X0"0H./_C*#C"```X`D0`>`XL(WE`$"$X0%0A>'8`\WA
M_X"@XP"0H.,(``#@"1`!X`0`@.$H0)WE!1"!X4B0G>4(P(SB\"#$X?@`Q.$)
M`%SA$$"$XBA`C>6Y__\:`*"@XX#`C>(`8.#C`'"@X]@&S.'0),SA@%"-X@C`
MC.+:@(7A`"`BX`$P(^#8`,SA""`BX`DP(^``("+@`3`CX`(`DN"B3Z#A`Q"C
MX(-`A.&C7Z#A!`"`X040@>$(H(KB!@``X`<0`>`"#%KC^`?,X>;__QIL<)WE
M;+"=Y7`<G^708,?A`XR-XFR0G>5L4)WE\&+-X="BR^'18(CA;!"=Y=B!R>'8
M0,7A\*#-X=`!P>$@P)WE^(#-X="`S>'X0<WA)$"=Y?`!S>$P#)_E"&"6X*RM
MH.&,(J#A"7"GX(2BBN$`8);@`!"@X]B!S>'00<WA`J"*X0%PI^#8(,WAV`'-
MX0I@EN`(@,+A`$`$X`F0P^$(0(3A`5`%X!@@G>4`<*?B"5"%X02@EN`<@)WE
M!;"GX"(!H.'XH\WA"+"@X0@/@.'8@\WA*Q&@X0(OH.$`((+A`3"`X0!@X./0
M`LWA`'"@XP:`".`'D`G@`F`&X`-P!^"`RY_E`[R-XOABS>$`8`;@`7`'X-R@
MB^'X9,WAT&'-X?"CS>&H3:#A`"#&X0$PQ^'88,WAT`/-X8BBH.&)0H3A!@"0
MX`<0H>`*0(3A\`3-X=@$S>'09,WA",",X@(`@.$#$('A)"N?Y?`#S>'0H\WA
M`F"6X``PH.,#<*?@"F"6X`MPI^`@L)WE!*"6X"!`G>4K`:#A`+"GX@!PH./P
MI,WA)+"=Y00OH.$`8.#C"P^`X="DS>$`((+A![`+X"1PG>4&H`K@)Q&@X0$P
M@.$#'(WBJFV@X=P`@>&+8H;AJWV@X?@$S>$``.#C`!"@XP(``.`#$`'@V"/-
MX?`#S>&*0J#A`"`"X`$P`^#8!,WA\"7-X=`AS>$"`)#@<"J?Y0,0H>``()+@
M`#"@XP$PH^#8`LWA^"/-X=`ES>$(`,#A"1#!X0`@@N$!,(/A!`"&X080A^'8
M0\WA\`7-X2@!H.%0P)WE`D"4X`D/@.$I$:#A""^@X0-0I>``((+A`3"`X0``
MX.,`$*#C#&"4X`(``.`#$`'@`'"EXMA)S>'X`\WA[`F?Y0`0H.,$`)#@!1"A
MX-!$S>'P!<WAV`/-X?ADS>$&@*#A`$`$X`%0!>#0!<WA\$3-X=A"S>$`8.#C
M!H`(X`!`E.`!4*7@T`/-X?A"S>'01,WA!Y"@X0H`P.$`<*#C"Q#!X0>0">`$
M`(#A!1"!X=A"S>&H;:#AB"*@X8EBAN$`0)3@`F"&X2H!H.$+#X#A`5"EX%3)
MG^4&0)3@*Q&@X0HOH.$!,(#A`%"EX@-LC>(`((+A`!"@XP``X.,"``#@`Q`!
MX/!$S>'<0(;A^`+-X1P)G^4`$*#C!`"0X`40H>#81,WA\`7-X=@"S>'0I,WA
M`&#@XP!`!.`!4`7@T`7-X?A$S>'00\WA!J`*X`!PH.,`0)3@`5"EX-@#S>'P
M0\WAV$3-X0@`P.$)$,'A![`+X`0`@.$%$('AT$/-X:IMH.&*(J#ABV*&X0!`
ME.`"8(;A*`&@X0D/@.$!4*7@""^@X09`E.`I$:#A`3"`X0!0I>(#;(WB`"""
MX0C`C.(``.#C`!"@XP(``.`#$`'@^$3-X=Q`AN'P`\WA5`B?Y0`0H.,$`)#@
M!1"AX-!$S>'P!<WAT`/-X=B$S>$`8.#C`$`$X`%0!>#0!<WA\$3-X=A#S>$&
M@`C@`'"@XP!`E.`!4*7@V`+-X?A#S>'01,WA"@#`X0L0P>$'D`G@!`"`X040
M@>'80\WAJ&V@X8@BH.&)8H;A`$"4X`)@AN$J`:#A"P^`X0%0I>`*+Z#A!D"4
MX"L1H.$!,(#A`%"EX@-LC>(`((+A",",X@``X.,`$*#C`@``X`,0`>#P1,WA
MW$"&X?@#S>&,!Y_E`!"@XP0`D.`%$*'@V$3-X?`%S>'8`\WAT*3-X0!@X.,`
M0`3@`5`%X`:@"N#X1,WAT`7-X=A"S>$`<*#C![`+X`!`E.`!4*7@T`/-X?A"
MS>'81,WA"`#`X0D0P>$$`(#A!1"!X=A"S>&J;:#ABB*@X8MBAN$`0)3@`F"&
MX2@!H.$)#X#A`5"EX`@OH.$&0)3@*1&@X0$P@.$`4*7B`VR-X@`@@N$(P(SB
M``#@XP`0H.,"``#@`Q`!X/A$S>'<0(;A^`+-X<0&G^4`$*#C!`"0X`40H>#0
M1,WA\`7-X=@"S>'8A,WA`&#@XP!`!.`!4`7@T`7-X?!$S>'00\WA!H`(X`!P
MH.,`0)3@`5"EX-@#S>'P0\WAT$3-X0H`P.$+$,'A!Y`)X`0`@.$%$('AT$/-
MX:AMH.&((J#AB6*&X0!`E.`"8(;A*@&@X0L/@.$!4*7@"B^@X09`E.`K$:#A
M`3"`X0!0I>(#;(WB`"""X0C`C.(``.#C`!"@XP(``.`#$`'@\$3-X=Q`AN'P
M`\WA_`6?Y0`0H.,$`)#@!1"AX-A$S>'P!<WAT`/-X="DS>$`8.#C`$`$X`%0
M!>#0!<WA^$3-X=A#S>$&H`K@`'"@XP!`E.`!4*7@V`+-X?A#S>'81,WA"`#`
MX0D0P>$'L`O@!`"`X040@>'80\WAJFV@X8HBH.&+8H;A`$"4X`)@AN$H`:#A
M"0^`X0%0I>`(+Z#A!D"4X"D1H.$!,(#A`%"EX@-LC>(`((+A",",X@``X.,`
M$*#C`@``X`,0`>#X1,WAW$"&X?@#S>$T!9_E`!"@XP0`D.`%$*'@T$3-X?`%
MS>'8`\WAV(3-X0!@X.,`0`3@`5`%X-`%S>'P1,WAV$+-X0:`".``<*#C`$"4
MX`%0I>#0`\WA^$+-X=!$S>$*`,#A"Q#!X0>0">`$`(#A!1"!X=A"S>&H;:#A
MB"*@X8EBAN$`0)3@`F"&X2H!H.$+#X#A`5"EX`HOH.$&0)3@*Q&@X0$P@.$`
M4*7B`VR-X@`@@N$(P(SB``#@XP`0H.,"``#@`Q`!X/!$S>'<0(;A^`+-X6P$
MG^4`$*#C!`"0X`40H>#81,WA\`7-X=@"S>'0I,WA`&#@XP!`!.`!4`7@T`7-
MX?A$S>'00\WA!J`*X`!PH.,`0)3@`5"EX-@#S>'P0\WAV$3-X0@`P.$)$,'A
M![`+X`0`@.$%$('AT$/-X:IMH.&*(J#ABV*&X0!`E.`"8(;A*`&@X0D/@.$!
M4*7@""^@X09`E.`I$:#A`3"`X0!0I>(#;(WB`"""X0C`C.(``.#C`!"@XP(`
M`.`#$`'@^$3-X=Q`AN'P`\WAI`.?Y0`0H.,$`)#@!1"AX-!$S>'P!<WAT`/-
MX=B$S>$`8.#C`$`$X`%0!>`&@`C@\$3-X=`%S>'80\WA`'"@XP>0">``0)3@
M`5"EX-@"S>'X0\WAT$3-X0H`P.$+$,'A!`"`X040@>'80\WAJ&V@X8@BH.&)
M8H;A`$"4X`)@AN$J`:#A"P^`X0%0I>`*+Z#A!D"4X"L1H.$!,(#A`%"EX@-L
MC>(`((+A",",X@``X.,`$*#C`@``X`,0`>#P1,WAW$"&X?@#S>'<`I_E`!"@
MXP0`D.`%$*'@V$3-X?`%S>'8`\WAT*3-X0!@X.,`0`3@`5`%X-`%S>'X1,WA
MV$+-X0:@"N``<*#C`$"4X`%0I>#0`\WA^$+-X=A$S>$(`,#A"1#!X0>P"^`$
M`(#A!1"!X=A"S>&J;:#ABB*@X8MBAN$`0)3@`F"&X2@!H.$)#X#A`5"EX`@O
MH.$&0)3@*1&@X0$P@.$`4*7B`VR-X@`@@N$(P(SB``#@XP`0H.,"``#@`Q`!
MX/A$S>'<0(;A^`+-X10"G^4`$*#C!`"0X`40H>#01,WA\`7-X=@"S>'8A,WA
M`&#@XP!`!.`!4`7@T`7-X?!$S>'00\WA!H`(X`!PH.,`0)3@`5"EX-@#S>'P
M0\WAT$3-X0H`P.$+$,'A!Y`)X`0`@.$%$('AT$/-X:AMH.&((J#AB6*&X0!`
ME.`"8(;A*@&@X0L/@.$!4*7@"B^@X09`E.`K$:#A`3"`X0!0I>(#;(WB`"""
MX0C`C.(``.#C`!"@XP(``.`#$`'@\$3-X=Q`AN'P`\WA3`&?Y0`0H.,$`)#@
M!1"AX-A$S>'P!<WAT`/-X="DS>$`8.#C`$`$X`%0!>#0!<WA^$3-X=A#S>$&
MH`K@`'"@XP!`E.`!4*7@V`+-X?A#S>'81,WA"`#`X0D0P>$'L`O@!`"`X040
M@>'80\WAJFV@X8HBH.&+8H;A`$"4X`)@AN$H`:#A"0^`X0%0I>`(+Z#A!D"4
MX"D1H.$!,(#A`%"EX@-LC>(`((+A",",X@``X.,`$*#C`@``X`,0`>#X1,WA
MW$"&X?@#S>&$`)_E`!"@XP0`D.`%$*'@T$3-X?`%S>'8`\WAV(3-X0!@X.,`
M0`3@`5`%X-`%S>'P1,WAV$+-X0:`".``<*#C`$"4X`%0I>#0`\WA^$+-X=!$
MS>$*`,#A"Q#!X0>0">`$`(#A!1"!X=A"S>&H;:#AB"*@X8EBAN$`0)3@#P``
MZH#]__^(_?__H/W__YEY@EHP_O__2/[__U#^__]8_O__8/[__VC^__]P_O__
M>/[__X#^__^(_O__D/[__Z'KV6X"8(;A*@&@X0L/@.$!4*7@"B^@X09`E.`K
M$:#A`3"`X0!0I>(#;(WB`"""X0C`C.(``.#C`!"@XP(``.`#$`'@\$3-X=Q`
MAN'X`LWAB``?Y0`0H.,$`)#@!1"AX-A$S>'P!<WAV`+-X="DS>$`8.#C`$`$
MX`%0!>`&H`K@^$3-X=`%S>'00\WA`'"@XP>P"^``0)3@`5"EX-@#S>'P0\WA
MV$3-X0@`P.$)$,'A!`"`X040@>'00\WAJFV@X8HBH.&+8H;A`$"4X`)@AN$H
M`:#A"0^`X0%0I>`(+Z#A!D"4X"D1H.$!,(#A`%"EX@-LC>(`((+A",",X@``
MX.,`$*#C`@``X`,0`>#X1,WAW$"&X?`#S>%0`1_E`!"@XP0`D.`%$*'@T$3-
MX?`%S>'0`\WAV(3-X0!@X.,`0`3@`5`%X-`%S>'P1,WAV$/-X0:`".``<*#C
M`$"4X`%0I>#8`LWA^$/-X=!$S>$*`,#A"Q#!X0>0">`$`(#A!1"!X=A#S>&H
M;:#AB"*@X8EBAN$`0)3@`F"&X0%0I>`&0)3@`%"EX@-LC>((P(SB*@&@X0L/
M@.$K$:#A"B^@X?!$S>$!,(#AW$"&X0`@@N$``.#C`@``X`PB'^4`$*#C!""2
MX`,0`>``,*#C!3"CX/@#S>'81,WA\"7-X=@CS>'0I,WA`&#@XP)`!.`#4`7@
MV"+-X?A%S>'01<WA!J`*X`!PH.,"0)3@`U"EX-@ES>'X1,WAT$/-X0>P"^"J
M;:#A"$#$X0E0Q>$$((+A!3"#X=A$S>&*`J#ABV*&X0)`E.`#4*7@`&"&X?A"
MS>'8(LWA",",XBA!H.$&()+@`#"CX@E/A.'X),WA`SR-XBE1H.'<8(/AV"3-
MX0@/H.$`D*#C`(#@XP@@`N`),`/@`("$X020A>'H0A_E\(7-X09`E.``4*#C
M!U"EX-!ES>'X1<WA`$#@XP!0H.,$8`;@!7`'X-!$S>'X9\WAHHV@X09`!.`'
M4`7@T&/-X?A"S>'81<WA@@*@X8."B.$$8);@!7"GX-A#S>'P8\WAV&+-X0I`
MQ.$+4,7A!D"$X0=0A>'08\WA`("(X0C`C.($8);@!7"GX`@`EN``$*?B`WR-
MXBI!H.'<8(?A\`3-X0M/A.$K4:#A"@^@X?!CS>$`H(3AT&3-X02PA>$`@.#C
M^*+-X0"0H.,(8`;@T`7-X0EP!^#8@LWAT$/-X::MH.$`@"C@H`,?Y0&0*>``
M0)3@`!"@XP%0I>#8!,WAAZ**X0@`(.`)$"'@V(/-X?@$S>%(P)WE"$"4X`E0
MI>`,@)3@`)"EXH8"H.'P@\WA`("*X=`#S>$B0:#A`T^$X0@`D.``$*'B`HR-
MXO@$S>$C4:#A`@^@X=@DS>'8K4CA`)"@XP"`X.,((`+@"3`#X`"`A.$$D(7A
MHDV@X?"#S>'8`LWA@T*$X6S$'^4`@"C@2`0?Y0&0*>``H)K@`!"@XP&PJ^#0
M!,WA)U&@X0@`(.`)$"'@V(?-X?@#S>&"`J#A"*":X`FPJ^`XD)WE`("$X0F@
MFN``L*OB"`":X``0J^(#C(WB\`3-X=R@B.'0A,WA)D&@X0=/A.$&#Z#A`'"@
MXP!@X.,&@`C@!Y`)X`!@A.$$<(7A!@"@X?ACS>$'$*#AT&/-X:A-H.&)0H3A
M!@`@X.AD'^4'$"'@"F"6X`!PH.,+<*?@V*3-X2-1H.$`H"K@`;`KX(@"H.'X
MI,WA*+"=Y4C`G>4+8);@`'"GX@R@EN``8(3A`+"GX@8`FN``$*OB`FR-XO@$
MS>'8K$;AV&3-X2)!H.$#3X3A`@^@X0`PH.,`(.#C`F`&X`-P!^``((3A!#"%
MX=A#S>'X(LWAI@V@X00@(N!\11_E!3`CX`I`E.``4*#C"U"EX-"DS>&'`H#A
M`J`JX`.P*^"&(J#A\*3-X3"PG>5`P)WE"T"4X`!0I>(,H)3@`D"`X0"PI>($
M`)K@`!"KX@*LC>+P!,WA*`&@X0D/@.$I$:#A""^@X="$S>'03$KA`+"@XP"@
MX.,*@`C@"Y`)X`*@@.$`L('AV"+-X?"CS>'0`\WA.,"=Y:BMH.$"`"#@'"8?
MY0,0(>`"0)3@`#"@XP-0I>#8),WAB:**X0`@(N`!,"/@#`"4X/`ES>%00)WE
M`!"EX@0`D.``$*'BB"*@X?@#S>$"0(KAV*/-X9#&'^4F`:#A!*":X`"PJ^('
M#X#A^*3-X2<1H.$#O(WB!B^@X=ADS>'<0(OA`*#@XP"PH.,*8`;@"W`'X`*@
M@.$`L('AT"/-X?BCS>'8`\WA*,"=Y::MH.$"`"#@Q"8?Y0,0(>`"0)3@`#"@
MXP-0I>#0),WAAZ**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'B
MAB*@X?@"S>$"0(KAV*+-X33''^4H`:#A!*":X`"PJ^()#X#A\*3-X2D1H.$#
MO(WB""^@X="$S>'<0(OA`*#@XP"PH.,*@`C@"Y`)X`*@@.$`L('AV"/-X?BB
MS>'8`LWA,,"=Y:BMH.$"`"#@;"<?Y0,0(>`"0)3@`#"@XP-0I>#8),WAB:**
MX0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BB"*@X?`#S>$"0(KA
MT*/-X=C''^4F`:#A!*":X`"PJ^('#X#A^*3-X2<1H.$#O(WB!B^@X=ADS>'<
M0(OA`*#@XP"PH.,*8`;@"W`'X`*@@.$`L('AV"+-X?"CS>'0`\WA.,"=Y::M
MH.$"`"#@%"@?Y0,0(>`"0)3@`#"@XP-0I>#0),WAAZ**X0`@(N`!,"/@#`"4
MX/`ES>%00)WE`!"EX@0`D.``$*'BAB*@X?@#S>$"0(KAV*/-X7S('^4H`:#A
M!*":X`"PJ^()#X#A\*3-X2D1H.$#O(WB""^@X="$S>'<0(OA`*#@XP"PH.,*
M@`C@"Y`)X`*@@.$`L('AT"/-X?BCS>'8`\WA*,"=Y:BMH.$"`"#@O"@?Y0,0
M(>`"0)3@`#"@XP-0I>#8),WAB:**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"E
MX@0`D.``$*'BB"*@X?@"S>$"0(KAV*+-X2#)'^4F`:#A!*":X`"PJ^('#X#A
M^*3-X2<1H.$#O(WB!B^@X=ADS>'<0(OA`*#@XP"PH.,*8`;@"W`'X`*@@.$`
ML('AV"/-X?BBS>'8`LWA,,"=Y::MH.$"`"#@9"D?Y0,0(>`"0)3@`#"@XP-0
MI>#0),WAAZ**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BAB*@
MX?`#S>$"0(KAT*/-X<3)'^4H`:#A!*":X`"PJ^()#X#A\*3-X2D1H.$#O(WB
M""^@X="$S>'<0(OA`*#@XP"PH.,*@`C@"Y`)X`*@@.$`L('AV"+-X?"CS>'0
M`\WA.,"=Y:BMH.$"`"#@#"H?Y0,0(>`"0)3@`#"@XP-0I>#8),WAB:**X0`@
M(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BB"*@X?@#S>$"0(KAV*/-
MX6C*'^4F`:#A!*":X`"PJ^('#X#A^*3-X2<1H.$#O(WB!B^@X=ADS>'<0(OA
M`*#@XP"PH.,*8`;@"W`'X`*@@.$`L('AT"/-X?BCS>'8`\WA*,"=Y::MH.$"
M`"#@M"H?Y0,0(>`"0)3@`#"@XP-0I>#0),WAAZ**X0`@(N`!,"/@#`"4X/`E
MS>%00)WE`!"EX@0`D.``$*'BAB*@X?@"S>$"0(KAV*+-X0S+'^4H`:#A!*":
MX`"PJ^()#X#A\*3-X2D1H.$#O(WB""^@X="$S>'<0(OA`*#@XP"PH.,*@`C@
M"Y`)X`*@@.$`L('AV"/-X?BBS>'8`LWA,,"=Y:BMH.$"`"#@7"L?Y0,0(>`"
M0)3@`#"@XP-0I>#8),WAB:**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`
MD.``$*'BB"*@X?`#S>$"0(KAT*/-X;#+'^4F`:#A!*":X`"PJ^('#X#A^*3-
MX2<1H.$#O(WB!B^@X=ADS>'<0(OA`*#@XP"PH.,*8`;@"W`'X`*@@.$`L('A
MV"+-X?"CS>'0`\WA.,"=Y::MH.$"`"#@!"P?Y0,0(>`"0)3@`#"@XP-0I>#0
M),WAAZ**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BAB*@X?@#
MS>$"0(KAV*/-X53,'^4H`:#A!*":X`"PJ^()#X#A\*3-X2D1H.$#O(WB""^@
MX="$S>'<0(OA`*#@XP"PH.,*@`C@"Y`)X`*@@.$`L('AT"/-X?BCS>'8`\WA
M*,"=Y:BMH.$"`"#@K"P?Y0,0(>`"0)3@`#"@XP-0I>#8),WAB:**X0`@(N`!
M,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BB"*@X?@"S>$"0(KAV*+-X=3,
MG^4F`:#A!*":X`"PJ^('#X#A^*3-X2<1H.$#O(WB!B^@X=ADS>'<0(OA`*#@
MXP"PH.,*8`;@"W`'X`*@@.$`L('AV"/-X?BBS>'8`LWA,,"=Y::MH.$"`"#@
M?"R?Y0,0(>`"0)3@`#"@XP-0I>#0),WAAZ**X0`@(N`!,"/@#`"4X/`ES>%0
M0)WE`!"EX@0`D.``$*'BAB*@X?`#S>$"0(KAT*/-X33,G^4H`:#A!*":X`"P
MJ^()#X#A\*7-X2D1H.$#O(WB""^@X="%S>'<0(OA`*#@XP"PH.,*@`C@"Y`)
MX`*@@.$`L('AV"+-X?"CS>'0`\WA.,"=Y:BMH.$"`"#@U"N?Y0,0(>`"0)3@
M`#"@XP-0I>#8),WAB:**X0`@(N`!,"/@#`"4X/@DS>%(0)WE`!"EX@0`D.``
M$*'BB"*@X?@#S>$"0(KAV*/-X9#+G^4F`:#A!*":X`"PJ^('#X#A^*/-X2<1
MH.$#O(WB!B^@X=ACS>'<0(OA`*#@XP"PH.,*8`;@"W`'X`*@@.$`L('AT"/-
MX?"DS>'0!,WA*,"=Y::MH.$"`"#@+"N?Y0,0(>`"0)3@`#"@XP-0I>#0)<WA
MAZ**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BAB*@X?@"S>$"
M0(KAV*+-X>S*G^4H`:#A!*":X`"PJ^()#X#A^*+-X2D1H.$#O(WB""^@X=B"
MS>'<0(OA`*#@XP"PH.,*@`C@"Y`)X`*@@.$`L('AT"3-X?BDS>'8!,WA,,"=
MY:BMH.$"`"#@A"J?Y0,0(>`"0)3@`#"@XP-0I>#8(\WAB:**X0`@(N`!,"/@
M#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BB"*@X?`#S>$"0(KAT*/-X4C*G^4F
M`:#A!*":X`"PJ^(#3(WB\*/-X=R@A.'00\WA!P^`X2<1H.$&+Z#A`'"@XP!@
MX.,&0`3@!U`%X`)@@.$`<('A!B"@X?ACS>'89,WA`'"@XT#`G>4&("+@W&F?
MY:0-H.$*8);@"W"GX-BBS>'P9<WAA0*`X0H@(N#0I<WAA&*@X0!@AN$,H)K@
M`+"KXKS)G^7XHLWAV*+-X0-\C>("H)K@`+"KX@@OH.'XHLWAV`+-X2BAH.$)
MKXKA!@"0X-Q@A^$IL:#A`!"AXO!ES>$"8(KA"G"+X=BCS>'0(\WA\`3-X0"`
MH.$!D*#A``#@XP`0H.,`@`C@`9`)X`H`AN$+$(?A`"`"X`$P`^#X8LWA\"/-
MX08@H.$',*#AV&/-X4P)G^4`$*#C!B`"X`<P`^#09<WA2,"=Y:BMH.$`8);@
M`7"GX-`#S>&)HHKA`@"`X0,0@>&((J#A\`7-X0P`EN!08)WE`!"GX@8`D.``
M$*'B`F"*X?`#S>'0H\WAU,B?Y20!H.$&H)K@!0^`X241H.$#7(WB`+"KX@0O
MH.'<0(7A^*3-X0I@H.$+<*#A`*#@XP"PH.,*8`;@"W`'X-BBS>'P1<WA`D"`
MX=`DS>$`4('A"Q"%X0H`A.$`(`+@`3`#X/!#S>'P),WA!""@X04PH.'80LWA
M>`B?Y0`0H.,$(`+@!3`#X-!%S>$XP)WEIJV@X0!`E.`!4*7@T`3-X8>BBN$"
M`(#A`Q"!X88BH.'P!<WA#`"4X%!`G>4`$*7B!`"0X``0H>("0(KA^`/-X=BC
MS>$$R)_E`UR-X@2@FN``L*OB*`&@X?"DS>'<0(7A"0^`X2D1H.$(+Z#A"Y"@
MX0J`H.$`L*#C`*#@XPJ`".`+D`G@T*/-X?!%S>$"0(#AV"3-X0!0@>$+$(7A
M"@"$X0`@`N`!,`/@^$/-X?@DS>$$(*#A!3"@X=!#S>&D!Y_E`!"@XP0@`N`%
M,`/@T$7-X2C`G>6HK:#A`$"4X`%0I>#8!,WAB:**X0(`@.$#$('AB"*@X?`%
MS>$,`)3@4$"=Y0`0I>($`)#@`!"AX@)`BN'X`LWAV*+-X33'G^4#7(WB!*":
MX`"PJ^+<0(7A)@&@X?BDS>$'#X#A)Q&@X08OH.$+<*#A"F"@X0"PH.,`H.#C
M"F`&X`MP!^#8H\WA\$7-X0)`@.'0),WA`%"!X0L0A>$*`(3A`"`"X`$P`^#X
M0LWA\"3-X00@H.$%,*#AV$/-X=`&G^4`$*#C!"`"X`4P`^#01<WA,,"=Y::M
MH.$`0)3@`5"EX-`$S>&'HHKA`@"`X0,0@>&&(J#A\`7-X0P`E.!00)WE`!"E
MX@0`D.``$*'B`D"*X?`#S>'0H\WA9,:?Y0-<C>($H)K@`+"KXMQ`A>$H`:#A
M\*3-X0D/@.$I$:#A""^@X0N0H.$*@*#A`+"@XP"@X.,*@`C@"Y`)X-BBS>'P
M1<WA`D"`X=@DS>$`4('A"Q"%X0H`A.$`(`+@`3`#X/!#S>'X),WA!""@X04P
MH.'80LWA_`6?Y0`0H.,$(`+@!3`#X-!%S>$XP)WEJ*V@X0!`E.`!4*7@V`3-
MX8FBBN$"`(#A`Q"!X8@BH.'P!<WA#`"4X%!`G>4`$*7B!`"0X``0H>("0(KA
M^`/-X=BCS>&4Q9_E`UR-X@2@FN``L*OBW$"%X28!H.'XI,WA!P^`X2<1H.$&
M+Z#A"W"@X0I@H.$`L*#C`*#@XPI@!N`+<`?@T*/-X?!%S>$"0(#AT"3-X0!0
M@>$+$(7A"@"$X0`@`N`!,`/@^$/-X?`DS>$$(*#A!3"@X=!#S>$H!9_E`!"@
MXP0@`N`%,`/@T$7-X2C`G>6FK:#A`$"4X`%0I>#0!,WAAZ**X0(`@.$#$('A
MAB*@X?`%S>$,`)3@4$"=Y0`0I>($`)#@`!"AX@)`BN'X`LWAV*+-X<3$G^4#
M7(WB!*":X`"PJ^+<0(7A*`&@X?"DS>$)#X#A*1&@X0@OH.$+D*#A"H"@X0"P
MH.,`H.#C"H`(X`N0">#8H\WA\$7-X0)`@.'8),WA`%"!X0L0A>$*`(3A`"`"
MX`$P`^#X0LWA^"3-X00@H.$%,*#AV$/-X50$G^4`$*#C!"`"X`4P`^#01<WA
MJ*V@X8FBBN$`0)3@`5"EX-@$S>$"`(#A`Q"!X8@BH.'P!<WA,,"=Y0P`E.!0
M0)WE`!"EX@0`D.``$*'B`D"*X?`#S>'0H\WA],.?Y0-<C>($H)K@`+"KXMQ`
MA>$F`:#A^*3-X0</@.$G$:#A!B^@X0MPH.$*8*#A`+"@XP"@X.,*8`;@"W`'
MX-BBS>'P1<WA`D"`X0!0@>'0!,WA\$/-X0I`A.$+4(7A!```X`40`>"00Y_E
M^`7-X=`#S>$`4*#C.,"=Y0H``.#0I<WAIBV@X8<B@N$*0)3@"U"EX(:BH.'P
M1,WAV$7-X0*@BN$I$:#A!`"`X=!$S>$(+Z#A`+"@XPQ`E.``4*7B`$"4X`!0
MI>(*0)3@`%"EXB@!H.'P1,WA_\#@XP-<C>()#X#AT(3-X=Q`A>$`H.#C"H`(
MX`N0">#0H\WA\$7-X0)`@.$`4('AV"3-X?A#S>$*0(3A`D`$X-@CS>$HP)WE
MJ`V@X0H@`N`+,`/@S**?Y?@DS>'0)<WA`+"@XXD"@.$"H)K@`["KX/"ES>'0
M)<WAV*3-X0"PH.,,()+@"D"$X0`PH^($()+@`#"CXHBBH.'X(LWAV$+-X0"@
MBN$F(:#A"D"4X`!0I>(`H.#C^$3-X0<O@N$G,:#A!@^@X0MP!>`*8`3@V*/-
MX0!`@N$"4(/AT"3-X?A"S>$*0(3A"U"%X00@`N#8HLWA!3`#X-A#S>'P),WA
MI@V@X06P"^`"7(WB!*`*X-@@Q>$00I_E`%"@XP0@DN`%,*/@T$3-X8<"@.$*
M0(3A"U"%X8:BH.'P1,WA,%"=Y4#`G>4%()+@`#"CX@"@BN$,0)+@*"&@X0DO
M@N$`4*/B"`^@X0I`E.``4*7B`*""X2DQH.'8`LWA`K"#X=@DS>'P1,WA!("@
MX060H.$`0.#C`%"@XP2`".`%D`G@`$"*X0%0B^$$(`+@!3`#X-A"S>'PH\WA
M^"3-X06P"^`"7(WB!*`*X-`AQ>%<09_E`%"@XP0@DN`%,*/@V$3-X:@-H.&)
M`H#A"D"$X0M0A>&(HJ#A^$3-X3A0G>5(P)WE!2"2X``PH^(`H(KA#$"2X"8A
MH.$'+X+A`%"CX@8/H.$*0)3@`%"EX@"@@N$G,:#AT`/-X0*P@^'0),WA^$3-
MX01@H.$%<*#A`$#@XP!0H.,$8`;@!7`'X`!`BN$!4(OA!"`"X`4P`^#00\WA
M^*/-X?`DS>$%L`O@`ER-X@2@"N#8(<7AI$"?Y0!0H.,$()+@!3"CX-!$S>&F
M#:#AAP*`X0I`A.$+4(7AAJ*@X?!$S>$H4)WE0,"=Y04@DN``,*/B`*"*X0Q`
MDN``4*/B"D"4X`!0I>(H(:#A"2^"X0@/H.'P1,WA`*""X2DQH.'8`\WA`K"#
MX0\``.J8_O__H>O9;J#^__^H_O__L/[__[C^___`_O__R/[__]#^___8_O__
MX/[__^C^___P_O__^/[__]R\&X_6P6+*V"3-X02`H.$%D*#A`$#@XP!0H.,$
M@`C@!9`)X`!`BN$!4(OA!"`"X`4P`^#80\WA^*+-X?@DS>$%L`O@`ER-X@2@
M"N#0(L7A6$`?Y0!0H.,$()+@!3"CX-A$S>&H#:#AB0*`X0I`A.$+4(7AB**@
MX?A$S>$P4)WE2,"=Y04@DN``,*/B`*"*X0Q`DN`F(:#A!R^"X0!0H^(&#Z#A
M"D"4X`!0I>(`H(+A)S&@X=@"S>$"L(/AT"3-X?A$S>$$8*#A!7"@X0!`X.,`
M4*#C!&`&X`5P!^``0(KA`5"+X00@`N`%,`/@V$+-X?"CS>'P),WA!;`+X`)<
MC>($H`K@V"+%X1!!'^4`4*#C!""2X`4PH^#01,WAI@V@X8<"@.$*0(3A"U"%
MX8:BH.'P1,WA.%"=Y4#`G>4%()+@`#"CX@"@BN$,0)+@*"&@X0DO@N$`4*/B
M"`^@X0I`E.``4*7B`*""X2DQH.'0`\WA`K"#X=@DS>'P1,WA!("@X060H.$`
M0.#C`%"@XP2`".`%D`G@`$"*X0%0B^$$(`+@!3`#X-!#S>'XH\WA^"3-X06P
M"^`"7(WB!*`*X-`CQ>'(01_E`%"@XP0@DN`%,*/@V$3-X:@-H.&)`H#A"D"$
MX0M0A>&(HJ#A^$3-X2A0G>5(P)WE!2"2X``PH^(`H(KA#$"2X"8AH.$'+X+A
M`%"CX@8/H.$*0)3@)S&@X0"@@N$`4*7B`K"#X?A$S>'XHLWAV`/-X=`DS>$$
M8*#A!7"@X0!`X.,`4*#C!&`&X`5P!^``0(KA`5"+X00@`N`%,`/@V$/-X?`D
MS>&F#:#A!;`+X`)<C>($H`K@V"/%X81"'^4`4*#C!""2X`4PH^#01,WAAP*`
MX0I`A.$+4(7AAJ*@X?!$S>$P4)WE0,"=Y04@DN``,*/B`*"*X0Q`DN`H(:#A
M"2^"X0!0H^((#Z#A"D"4X`!0I>(`H(+A*3&@X=@"S>$"L(/AV"3-X?!$S>$$
M@*#A!9"@X0!`X.,`4*#C!(`(X`60">``0(KA`5"+X00@`N`%,`/@V$+-X?"C
MS>'X),WA!;`+X`)<C>($H`K@T"3%X3A#'^4`4*#C!""2X`4PH^#81,WAJ`V@
MX8D"@.$*0(3A"U"%X8BBH.'X1,WA.%"=Y4C`G>4%()+@`#"CX@"@BN$,0)+@
M)B&@X0<O@N$`4*/B!@^@X0I`E.``4*7B`*""X2<QH.'0`\WA`K"#X=`DS>'X
M1,WA!&"@X05PH.$`0.#C`%"@XP1@!N`%<`?@`$"*X0%0B^$$(`+@!3`#X-!#
MS>'XH\WA\"3-X06P"^`"7(WB!*`*X-@DQ>'P0Q_E`%"@XP0@DN`%,*/@T$3-
MX:8-H.&'`H#A"D"$X0M0A>&&HJ#A\$3-X2A0G>5`P)WE!2"2X``PH^(`H(KA
M#$"2X"@AH.$)+X+A`%"CX@@/H.$*0)3@`%"EX@"@@N$I,:#AV`/-X0*P@^'8
M),WA\$3-X02`H.$%D*#A`$#@XP!0H.,$@`C@!9`)X`!`BN$!4(OA!"`"X`4P
M`^#XHLWA^"3-X=A#S>&H#:#AB0*`X06P"^`"7(WB!*`*X-`EQ>&P1!_E`%"@
MXP0@DN`%,*/@V$3-X0I`A.$+4(7AB**@X?A$S>$P4)WE2,"=Y04@DN``,*/B
M#$"2X"8AH.$'+X+A`*"*X08/H.$`4*/B"D"4X"<QH.$`H(+AV`+-X0!0I>("
ML(/AT"3-X?"CS>'X1,WA`*"*X0&PB^$$8*#A!7"@X0!`X.,`4*#C!&`&X`5P
M!^`*(`+@T$/-X0LP`^#8HLWA\"7-X:8-H.$*0`3@"U`%X(<"@.'P1,WA`ER-
MXFQ%'^78)<7A`%"@X]"DS>$$()+@!3"CX-!%S>'X)<WAAB*@X02@BN$%L(OA
MV$7-X?"DS>$XH)WE0,"=Y0I`E.``4*7B`"""X0R@E.``L*7B`@":X``0J^(H
M0:#A\`3-X0E/A.$I4:#A"`^@X=`DS>$`H(3A!+"%X0"`X./XH\WA`)"@XP@@
M`N`),`/@T`/-X=B#S>$"'(WB*,"=Y=!&P>$`@"C@#`8?Y0`0H.,`0)3@`5"E
MX**MH.'P1<WAV$3-X8.BBN&"`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@
M`%"EX@"`BN'X0LWAV`+-X29!H.$'3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`
MH(3AV&3-X02PA>$`@.#C^*+-X=@#S>$(8`;@"7`'X`(<C>+8@LWAV$;!X0`0
MH.,`@"C@J`8?Y3#`G>4`0)3@`5"EX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`H
MX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'P0\WAT`/-X2)!H.$#3X3A
M"`"0X``0H>(C4:#A\`3-X0(/H.$`H(3AT"3-X02PA>$`@.#C\*/-X0@@`N`)
M,`/@V`+-X="#S>$"'(WB.,"=Y=!'P>$`@"C@1`<?Y0`0H.,`0)3@`5"EX**M
MH.'P1<WAV$3-X8.BBN&"`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"E
MX@"`BN'X0\WAV`/-X29!H.$'3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3A
MV&3-X02PA>$`@.#C^*/-X0A@!N`)<`?@T`/-X=B#S>$"'(WB*,"=Y=A'P>$`
M@"C@X`<?Y0`0H.,`0)3@`5"EX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%
MS>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0LWAV`+-X2)!H.$#3X3A"`"0
MX``0H>(C4:#A\`3-X0(/H.$`H(3AT"3-X02PA>$`@.#C^*+-X=@#S>$((`+@
M"3`#X`(<C>+8@LWAT$C!X0`0H.,`@"C@?`@?Y3#`G>4`0)3@`5"EX**MH.'P
M1<WAV$3-X8.BBN&"`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`
MBN'P0\WAT`/-X29!H.$'3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-
MX02PA>$`@.#C\*/-X0A@!N`)<`?@V`+-X="#S>$"'(WB.,"=Y=A(P>$`@"C@
M&`D?Y0`0H.,`0)3@`5"EX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`
MD*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0\WAV`/-X2)!H.$#3X3A"`"0X``0
MH>(C4:#A\`3-X0(/H.$`H(3AT"3-X02PA>$`@.#C^*/-X0@@`N`),`/@T`/-
MX=B#S>$"'(WB*,"=Y=!)P>$`@"C@M`D?Y0`0H.,`0)3@`5"EX**MH.'P1<WA
MV$3-X8.BBN&"`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X
M0LWAV`+-X29!H.$'3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02P
MA>$`@.#C^*+-X=@#S>$(8`;@"7`'X`(<C>+8@LWAV$G!X0`0H.,`@"C@4`H?
MY3#`G>4`0)3@`5"EX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C
M#$"4X`!0I>((0)3@`%"EX@"`BN'P0\WAT`/-X2)!H.$#3X3A"`"0X``0H>(C
M4:#A\`3-X0(/H.$`H(3AT"3-X02PA>$`@.#C\*/-X0@@`N`),`/@V`+-X="#
MS>$"'(WB.,"=Y=!*P>$`@"C@[`H?Y0`0H.,`0)3@`5"EX**MH.'P1<WAV$3-
MX8.BBN&"`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0\WA
MV`/-X29!H.$'3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`
M@.#C^*/-X0A@!N`)<`?@T`/-X=B#S>$"'(WB*,"=Y=A*P>$`@"C@B`L?Y0`0
MH.,`0)3@`5"EX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4
MX`!0I>((0)3@`%"EX@"`BN'X0LWAV`+-X2)!H.$#3X3A"`"0X``0H>(C4:#A
M\`3-X0(/H.$`H(3AT"3-X02PA>$`@.#C^*+-X=@#S>$((`+@"3`#X`(<C>+8
M@LWAT$O!X0`0H.,`@"C@)`P?Y3#`G>4`0)3@`5"EX**MH.'P1<WAV$3-X8.B
MBN&"`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'P0\WAT`/-
MX29!H.$'3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C
M\*/-X0A@!N`)<`?@V`+-X="#S>$"'(WB.,"=Y=A+P>$`@"C@P`P?Y0`0H.,`
M0)3@`5"EX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0
MI>((0)3@`%"EX@"`BN'X0\WAV`/-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-
MX0(/H.$`H(3AT"3-X02PA>$`@.#C^*/-X0@@`N`),`/@T`/-X=B#S>$"'(WB
M*,"=Y=!,P>$`@"C@;`6?Y0`0H.,`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"
M`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0LWAV`+-X29!
MH.$'3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C^*+-
MX=@#S>$(8`;@"7`'X`(<C>+8@LWAV$S!X0`0H.,`@"C@T`2?Y3#`G>4`0)3@
M`5"EX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((
M0)3@`%"EX@"`BN'P0\WAT`/-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-X0(/
MH.$`H(3AT"3-X02PA>$`@.#C\*/-X0@@`N`),`/@V`+-X="#S>$"'(WB.,"=
MY=!-P>$`@"C@-`2?Y0`0H.,`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"`J#A
M!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0\WAV`/-X29!H.$'
M3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C^*/-X0A@
M!N`)<`?@T`/-X=B#S>$"'(WB*,"=Y=A-P>$`@"C@F`.?Y0`0H.,`0)3@`5"E
MX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@
M`%"EX@"`BN'X0LWAV`+-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-X0(/H.$`
MH(3AT"3-X02PA>$`@.#C^*+-X=@#S>$((`+@"3`#X`(<C>+8@LWAT$[!X0`0
MH.,`@"C@_`*?Y3#`G>4`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"`J#A!(`H
MX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'P0\WAT`/-X29!H.$'3X3A
M"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C\*/-X0A@!N#8
M`LWA"7`'X`(<C>+0@\WAV$[!X0`0H.,`@"C@8`*?Y3C`G>4`0)3@`5"EX*:M
MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$,0)3@`%"EX@A`E.``4*7B`("*
MX?A#S>'8`\WA`JR-XB)!H.$(`)#@`!"AXM"/RN'P!,WAT*3-X0-/A.$C4:#A
M`@^@X0`PH.,`(.#C`J`*X`.P"^``((3A!#"%X0(`H.'X(\WAT"/-X0`PH.,H
MP)WE`@`@X,`AG^6J3:#A"""2X`DPH^#8A,WA#""2X``PH^((`"#@`""2X``P
MH^*+0H3A^"+-X8J"H.$$@(CAV$+-X28!H.$'#X#A"$"4X"<1H.$&+Z#A`%"E
MX@"`X.,`D*#C"$`$X`E0!>`"@(#A`)"!X0!@H.,`<*#C`AR-XOAES>'XA,WA
MV"_!X:2=H.%8D(WE*L&@X3`!G^7X8LWA*,"-Y5APG>4PP)WE`""2X``0H.,!
M,*/@A7*'X0Q@DN!8<(WE`'"CXB@PG>6E+:#A"S^#X?!ES>%<((WE*#"-Y=AD
MS>'8(\WAA(*@X0H/H.$"8";@`W`GX-`DS>$XP)WE`F`FX`-P)^#0)<WA\&/-
MX3!@G>4&()+@V&7-X0A@AN$K@:#A+("-Y=B"S>'0H,WA!B"2X`"`B.'8`<WA
M#*":X`"PJ^(`0)3@`5"EX-@`S>%(8)WE`)"@XP8`D.#08LWA`!"AX@N0">`"
M8);@T"'-X0!PI^(`L*#C"""2X``PH^(`@.#C"H`(X`M0!>``H.#C"Q`!X`MP
M!^`+,`/@;+"=Y0I`!.`*``#@"F`&X`H@`N#P8,OA^$#+X?@!R^'P@LOA\"'+
MX0/<C>+P#[WH'O\OX=;!8LKX0RWI`'!0X@&0H.$K```*L#"?Y0"`D^4``%CC
M)0``"@!@U^4]`%;C``!6$P!@H`,!8*`3$0``&@!`F.4``%3C#```"@A0H.$$
M`*#A!Q"@X08@H.$R\/_K``!0XP(``!H&,-3G/0!3XPP```H$0+7E``!4X_/_
M_QH$`*#A^(.]Z`$PA^(#8*#A`2#3Y#T`4N,``%(3^O__&@9@9^#E___J!5!H
MX`$`AN)%4:#A`%")Y0``A.#X@[WH"`"@X?B#O>@'`*#A^(.]Z$#6`0`P0"WI
M`$"@X5!0G^4,T$WB!`"@X000C>+%___K``!0XPP```H$$)WE`""5Y0$Q@N`$
MP)/E``!<XP'!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J#-"-XC"`
MO>A`U@$`\$\MZ0%`H.$`,-'E#-!-X@!@H.$]`%/C`4"!`@0`H.&<[__K!!"-
MX@!PH.$&`*#AIO__ZP!04.)````*E>__ZP``5^$T``":!("=Y:"1G^4(@:#A
M`,#6Y3T`7.,``%P3`,"@`P'`H!,&```*`3"&X@/`H.$!$-/D/0!1XP``41/Z
M__\:#,!FX`(`A^(,`(#@`%"9Y6WO_^M4,9_E``!0XP@`A>=0```*`""3Y000
MG>4`,-;E`1&2YP``4^,`,,'E"P``"CT`4^,)```*!@"@X0$@@>(!``#J/0!3
MXP0```H!,/#E`A"@X0``4^,!,,+D^/__&@$@H.$],*#C`##!Y0$PU.0``%/C
M`3#BY?O__QH``*#C#-"-XO"/O>@!,-3D``!3XP$PQ>3X__\*`3#4Y```4^,!
M,,7D]___&O/__^JLD)_E`*"9Y0`PFN4``%/C(@``"@HPH.$$(+/E`5"%X@``
M4N/[__\:`A"%X@$1H.&`,)_E`""3Y0``4N,*```*"@"@X1#O_^L``%#C``")
MY14```H%@:#A`3"%X@`@H.,#(8#G!%"-Y:G__^H!(*#C`0"@X0`@@^4D[__K
M`+!0X@D```H%@:#A"A"@X0@@H.'9[O_K"P"@X0"PB>7M___J`U"@X0@0H./@
M___J``#@X\?__^I`U@$`8-8!`/!`+>D`0%#B;-!-X@(```H`,-3E``!3XP$`
M`!ILT(WB\("]Z`3O_^L`8%#B^O__"@8`H.%@[__K`!!0XA-0@>($`*#A)@``
M"A,@T>4N`%+C&@``"A#O_^L`<*#A!0"@X0WO_^L``(?@`@"`XOCN_^L%,*#A
MB!"?Y00@H.$`<*#A2N__ZP<0H.$#`*#C#2"@X57O_^L!`'#C!P"@X0,```H0
M,)WE#SH#X@$)4^,2```*P^[_ZP<`H.&C[O_KV___ZA0PT>4``%/CV/__"BX`
M4^/?__\:%3#1Y0``4^/3__\*V___Z@8`H.%.[__K!`"@X:3N_^MLT(WB\("]
MZ+___^OK___JD/0``'!`+>D(09_E``"4Y4;O_^MX,)#E``"4Y010D^5"[__K
M96#0Y0``E.4_[__K?V`&X@0PD.6P,=/A@SN@X2-HAN&R8,7A``"4Y3?O_^MX
M,)#E``"4Y010D^4S[__KM!"?Y0`@H./6[O_K'`"%Y0``E.4M[__K>#"0Y0``
ME.4$4)/E*>__ZQPUD.4``)3E(#"%Y27O_^MX,)#E``"4Y010D^4A[__K-#&0
MY0``4^,#```*``"4Y1SO_^LT,9#E<#"3Y20PA>4``)3E%^__ZP!0H.-X,)#E
M``"4Y00PD^4H4(/E$>__ZW@PD.4``)3E!#"3Y1A0@^4,[__K>#"0Y0``E.4$
M0)/E".__ZU`RD.4L,(3E<("]Z%#6`0"L]P``.$`MZ0!0H.%L0)_E``"4Y?[N
M_^L%$*#A!2V`X@,`H./T[O_K``!0XP$```H``*#C.("]Z```E.7T[O_K4#&0
MY0\Z`^(!"5/C!0``"@``E.7N[O_K4#&0Y0\Z`^(*"E/C\?__&@4`H.$"$*#C
MM^[_ZP$`<.(``*`S.("]Z%#6`0#P0"WI`=I-XL!0G^4,T$WB`LJ-X@`PE>4`
M8*#A`7"@X:P`G^4$$(WBJ""?Y?P_#.5&[O_K``!0XQP``-H!0$#B!#"-X@0@
MT^<``%+C%0``"@!`H.$$`(WB+Q"@XP0@H.&7[O_K``!0XQ````IH,)_E``"3
MY<7N_^L&$*#A!""-X@0PH.&F[O_K`LJ-XOPO'.4`,)7E`P!2X0L``!H!VHWB
M#-"-XO"`O>@``%3CZ/__&B0PG^4``)/EM.[_ZP80H.$'(*#A'N[_Z^[__^H-
M[O_K2-8!`)CT``#_#P``4-8!`!PPG^400"WI``"3Y:?N_^L0$)_E$""?Y1`P
MG^400+WH5.[_ZE#6`0"H]```O)4``,3T```00"WI"-!-XC1`G^4``)3EF>[_
MZ^S__^L``)3EEN[_ZR`PG^4`(*#C!""-Y0`PC>44$)_E%""?Y5GN_^L(T(WB
M$("]Z%#6`0"L]P``T/0``$CO``!P0"WI`MI-XJA0G^40T$WB`BJ-X@`PE>4,
M,(+E%>[_ZY00G^64,)_E`""@X00`C>);[O_K``!0XQD``+H!&HWB!`"-X@@0
M@>(!*J#CY>W_ZP!`4.(2``"Z`0"$XOGM_^L`8%#B$```"@$:C>(($('B!""@
MX;?M_^L&`*#A`#"@XP0PQN<".HWB#""3Y0`PE>4#`%+A!@``&@+:C>(0T(WB
M<("]Z```H./U___J!@"@X?/__^JY[?_K2-8!`.CT``#T]```S?__ZO!/+>D!
MVDWBF*&?Y1303>("*HWB`#":Y0!0H.$!8*#AA`&?Y0@0C>+T/P+E\_W_ZR\0
MH.,`0*#A!0"@X>?M_^L``%#C"P``"F`!G^4%$*#A-O[_ZP4`H.$".HWB]"\3
MY0`PFN4#`%+A30``&@':C>(4T(WB\(^]Z`4`H.'1[?_K+!&?Y0"0H.$&`*#A
M">[_ZP"P4.+K__\*&'&?Y1B!G^4889_E`##;Y0``4^,'L*`!``!4XP0```H$
M`*#A"Q"@X5WM_^L``%#C)```"@L`H.&\[?_K`#"+X`$@4^4O`%+C!0``&@`@
MH.,!(&/E`>!3Y0$`0.(O`%[C^O__"@'`@.()P(S@"`!<X<[__\H+(*#AK!"?
MY:PPG^4`4(WE#`"-XNWM_^L``);E#.[_ZPP0C>(%+8#B`P"@X_;M_^L``%#C
M!0``&@``EN4$[O_K4#&0Y0\Z`^(""5/C!@``"@``H.-,$)_ET^W_ZP``4.,`
ML*#AR___&K/__^H,`(WB`1"@X\;M_^L``%#C\___&@P0C>(8`)_EY?W_ZPP`
MC>*>[?_KK/__ZDOM_^M(U@$`_/0```CU```8]0``^/0``/\/``!0U@$`'/4`
M`"3U````,-#E``!3XQ[_+P$!((#B+P!3XP(`H`$!,-+D``!3X_K__QH>_R_A
M$$`MZ0!`4.(K```*`##4Y0``4^,H```*;>W_ZP$`0.(`,(3@`P!4X0L``"H`
M(-3G+P!2XRD``!H!($/B`P``Z@`0TN4!($+B+P!1XR,``!H$`%+A`C"@X?C_
M_QH$`%/A`3!#$@0``!H0``#J`!#3Y0$P0^(O`%'C`@``&@,`5.$#(*#A^/__
M.@(@9.`",(+B`0I3XP\``(H$$*#A`2""XFP`G^5N[?_K9`"?Y1"`O>@`,-/E
M+P!3XQ(``!H"`*#C,>W_ZP``4.,"```*+C"@X[`PP.$0@+WH``"@XQ"`O>@!
M($/B`P``Z@`0TN4!($+B+P!1X]C__PH"`%3A`C"@X?C__SK4___J"`"?Y1!`
MO>A$[?_J9-8!`"3U```P0"WI--!-XE#AG^4(P(WB3$&?Y0\`ON@`4)3E#P"L
MZ`\`ON@L4(WE`.">Y0\`K.@P`9_EL.#,X5_]_^LH`9_E7?W_ZR0!G^5;_?_K
M(`&?Y5G]_^L<`9_E5_W_ZQ@!G^55_?_K%`&?Y5/]_^L0`9_E4?W_ZPP!G^5/
M_?_K"`&?Y4W]_^L$`9_E2_W_ZP`!G^5)_?_K_`"?Y4?]_^L$$(WB]`"?Y1']
M_^L`$%#B`0``"M``G^59_?_K!!"-XMP`G^4*_?_K`!!0X@$```K0`)_E4OW_
MZP00C>+(`)_E`_W_ZP`04.(*```*D`"?Y4O]_^N``)_EL!"?Y4C]_^LL()WE
M`#"4Y0,`4N$3```:--"-XC"`O>@$$(WBD`"?Y?/\_^L`$%#B`@``"E0`G^4[
M_?_K[O__ZAD`C>)T$)_E"B"@XS/M_^L``%#CZ/__&B,0C>(L`)_E,?W_Z^3_
M_^J9[/_K(/0``$C6`0`H]0``-/4``#SU``!(]0``4/4``&#U``#\]```;/4`
M`'CU``"$]0``"/4``)#U``"<]0``J/4``+SU``#0]0``W/4```SV``#L]0``
M`/8``!!`+>D(T$WB1$"?Y0``E.4!`'#C`0``"@C0C>(0@+WH,`"?Y000C>+"
M_/_K``!0XP0```H``-#E``!0XP$```HP`%#B`0"@$P``A.4(T(WB$("]Z#36
M`0!L]0``"$`MZ4SL_^M%[/_K``!0XP``D!4(@+WH\$$MZ0!PH.',0)_E*-!-
MX@S`C>(/`+3H#P"LZ`<`E.@,0)WE``!4XP<`C.@6```*#%"-X@4``.HM[/_K
M``!0XQ,```H$0+7E``!4XPX```H($(WB!`"@X9G\_^L'$*#A`&!0X@(```H`
M,-;E``!3X_#__QH$`*#A!Q"@X=S\_^L$0+7E``!4X_#__QHHT(WB\(&]Z`<`
MH.%[[/_K`("@X08`H.%X[/_K``"(X`(`@.)C[/_K`&"-Y2`0G^4'(*#A'#"?
MY0"`H.&T[/_K!`"@X0@0H.'&_/_KV?__ZD3T```<]0``&/4``(PYG^7P3RWI
M`%"@X8'<3>('`)/H--!-XCA`C>(,X(/B!P"$Z"1@@^(/`+[H4,"-XD1`C>(/
M`*SH`P">Z%0IG^4#`(SH`#"2Y0<`EN@":8WB+#&&Y0<`A.@T$(WB.`F?Y5W\
M_^L`0%#B`@``"@`PU.4``%/C_@``&J#__^L`<%#B0$"-`DP```H'`*#A1.S_
MZX``H.$!`(#B+^S_ZP`@U^4``%+C`$"@X0!@H!$&```*!@"@X>08G^5^[/_K
M`2#WY0)@AN(``%+C^/__&M`XG^6!S(WB,,",X@,`G.<``%#C4&"-$@,``!H0
M``#J!`"VY0``4.,-```*-!"-XC;\_^L`<%#B^/__"@`PU^4``%/C]?__"H3]
M_^L``%#C\O__"@<`H.$S[/_K`(!0XBX``!IP.)_E@0R-XC``@.(#8)#G``!6
MXR<```H`,-;E``!3XP%PH!,+```:(@``ZH$<C>(P$('B!S&!X`(Y0^+X8!/E
M``!6XQL```H`,-;E`7"'X@``4^,7```*!@"@X6;]_^L``%#C\/__"@8`H.$5
M[/_K``!0X^S__PH`@*#A#@``ZA#L_^L``%#CJP``&@0`M.4``%#CK@``"C00
MC>("_/_K`#!0XOC__PH`,-/E``!3X_7__PKQ___J`("@XP@`H.'KZ__K`&"@
MX00`H.'HZ__K``"&X`%K@.($8(;B!@"@X='K_^N0-Y_E"""@X0`PC>6(%Y_E
MB#>?Y01`C>4`L*#A(.S_ZPL`H.$'':#C\^O_ZP$`<.,8```*:$>?Y0``E.4Y
M[/_K"Q"@X04M@.(#`*#C+^S_ZP``4.,<```*2!>?Y0`@E>4+,*#A``"1Y3P7
MG^70Z__K``"@XPA7G^4"&8WB+"&1Y0`PE>4#`%+AN0$`&H'<C>(TT(WB\(^]
MZ,OK_^L`,)#E$0!3X^+__PKX%I_E`""5Y0`PC>4+,*#A``"1Y>P6G^6[Z__K
M``"@X^G__^H``)3E%.S_ZU`QD.4/.@/B`0E3X]S__QH``)3E#NS_ZUAQD.5,
MZ__K``!7X=;__QH``)3E".S_ZU`QD.6#.Z#A#@)3X]#__QH&`*#ABNO_ZS00
MC>(`H*#AB`:?Y:;[_^L``%#CD`$`"@!`E>6IZ__K`!"@X00`H.&?_?_K`$!0
MXHD!``H$`*#AC>O_ZP,`4.,`8*#A"P``V@0`0.(``(3@1!:?Y2/K_^L``%#C
M!0``&@0`5N,W`0`*!F"$X`4P5N4O`%/C,P$`"KW^_^L`$%#B!```&@0`H.%D
MZ__K`%!0XB!0C>4Q```:`!:?Y0`&G^7-^__K;.O_Z_A5G^7X%9_E!%"-Y0L@
MH.'$-9_E`$"@XP``C>4*`*#AKNO_ZPP``.IVZ__K`#"0Y1$`4^,-```:7>O_
MZP%`A.+`%9_E,`"-Z0L@H.&(-9_E``"-Y0H`H.&@Z__K"@"@X0<=H.-SZ__K
M`0!PX^W__PH+`*#A`.O_ZPH0H.%`!9_EJ_O_ZPH`H.&L_O_K"@"@X8;__^H`
M<*#A!/__ZJ?^_^L$`*#A7>O_ZX#__^I8=9_E#0"@XP'__^H"0*#C`##@XQ$@
MX.,`0(WE'NO_ZTL?C>(@`)WE!B"@X][J_^N!;(WB*#6?Y3!@AN(#,-;G``!3
MXP(``!HM,=WE0P!3XPP!``H`0*#C`$"-Y0`@H.,`,*#C(`"=Y0OK_^OT))_E
M`#"@X_`$G^4`$*#C\"O-X0`PH.,`(*#C^`O-X=S$G^7<9)_E($&-Y=@$G^78
M1)_E\"W-X?@MS>&!/(WB`'"@XP!0H.,`$*#C,#"#XN"`C>+P;,WA^$S-X?P`
M@^$D@(WE**"-Y2RPC>4@`)WE2Q^-X@(IH..PZO_K`)!0XE<``-K)7Z#AB<&@
MX85AH.&I?H;A%'"-Y1#`C>70#<WAT&'-X0`@X.,`,*#C`&"6X`%PI^`"8`;@
M`W`'X`<`4>$&`%`!"4"@X=BMS>$!``":`:":X@"PJ^*D/J#AA<&#X:4.H.$8
MP(WE'`"-Y=@AS>$@$9WE\&W-X0*@FN`#L*O@``!1X_BMS>$S```*0%!AX@D`
M5>$)4*"A.`"!XJ@PC>(%(*#A``"#X$L?C>*2ZO_K("&=Y0(@A>!``%+C("&-
MY<G__QI+;XWBJ`"-X@F09>`%4(;@%.S_ZS\`6>,8``#:0*!)XH!@A>(J<Z#A
M0+"%X@=CAN!`0$OB"."@X0``E.4$$)3E"""4Y0PPE.4.P*#A$$"$X@L`5.$/
M`*SH#."@X?7__QJH`(WB0+"$XO[K_^L&`%OA[O__&@$@A^('DTK@`E.%X`40
MH.$D`)WE"2"@X6GJ_^L@D8WEH___ZDM?C>+<___J(`"=Y2B@G>4LL)WE#.O_
MZ]!`G>6!?(WB,'"'XJ0AH.$_(`+B`C"'X`$`@N(".4/B?Q#@XS@`4./84)WE
M4!!#Y3D`@N)D``#*J!"-X@``@>`W(&+B`!"@X[KJ_^LE?*#AN&*?Y1AQS>6!
M?(WB,'"'XB7HH.$EQ*#A)!R@X20HH.$D-*#AJ`"-XAM1S>4?0<WE&>'-Y1K!
MS>4<$<WE'2'-Y1XQS>7'Z__K!N"7YWQ"G^6PP)WE+BR@X;@`G>4$(,?G:^#-
MY2Y(H.$NY*#A:N#-Y2SLH.'`$)WE;\#-Y6S@S>4LZ*#A+,2@X<@PG>5NP,WE
M(,R@X7,`S>5PP,WE(,B@X2`$H.%QP,WE<@#-Y2',H.$A"*#A=Q#-Y7LPS>4A
M%*#A=,#-Y74`S>4CS*#A(PB@X2,TH.%I0,WE:%"-XGQ`C>*D8(WB;>#-Y780
MS>5XP,WE>0#-Y7HPS>4```#J`2#UY00`H.%@$9_E`D"$XISJ_^L&`%3A^/__
M&H0QG^5\((WB`,"@XPP`C>@*`*#AH!&?Y0L@H.%$,9_EI,#-Y9#J_^OS_O_J
M!%"5Y0``5>/(_O\*!0"@X47J_^L#`%#CQ/[_F@0`0.(``(7@:!&?Y=SI_^L`
M`%#C!4"@`;W^_^JHP(WB``",X#\@8N(`$*#C5>K_ZZ@`C>)SZ__K`#"@X^`P
MC>7D,(WEZ#"-Y>PPC>7P,(WE]#"-Y?@PC>7\,(WE`#&-Y00QC>4(,8WE##&-
MY1`QC>44,8WEB/__ZBXQW>5!`%/C[_[_&B\QW>5#`%/C[/[_&C`QW>5(`%/C
MZ?[_&C$QW>5%`%/CYO[_&@`PX.,`0(WE(`"=Y3D@X./SZ?_K2Q^-XB``G>4I
M(*#CL^G_ZW`PG^5+?XWB!#"-Y0!PC>4*`*#AC!"?Y0L@H.$P,)_E3.K_ZZ_^
M_^K)Z?_K`$"5Y7/^_^I@]```2-8!`/ST```8]@``('___PA___\L]@``(/8`
M`"3U``!0U@$`6-8!`+3V```T]@```/@``'#V```,]@``;/4``*SW``"0]@``
MH/8``!#V``#\?___B:O-[_[<NIAX?___=E0R$`$C16?PX=+#.'___X#V``!X
M]@``\$\MZ0S03>)8@Y_E``"8Y47J_^L!,*#C!!"-XF$PP.5$`Y_EZ/G_ZP``
M4.,"```*`##0Y3$`4^.(```*IOS_ZP``F.4XZO_K(!.?Y0$@H.,+,*#CPNG_
MZQ1CG^4``%#C+@``"A`@D.7T/Q;E`0!3XQB0DN4I``#:Z**?Y0!0H.,!0*#C
M"0``ZA`0DN4+`*#A7.G_Z_0_%N4``%#C'```&@%`A.($`%/A`5"%XA@``-H`
M`)CE'.K_ZPD0H.$%(*#A`#"@X_'I_^L`<%#B#P``"@`@E^6<,I_E\!\6Y0@`
MDN4#,`#@`0M3XP2QD>?E__\*``":Y0SJ_^L`$)?E`""@XP(PH.-[Z?_K`!"@
MX=[__^KT/Q;E`2!#X@4`4N$]```*``"8Y0#J_^M,$I_E`2"@XP0PH..*Z?_K
M*%*?Y0!`4.(*```*``"5Y??I_^L0,)3E*"*?Y0`0D^5@Z?_K$#"4Y0`PD^4(
M,)/E`043XS4``!H``)CE[.G_ZP02G^4!(*#C!#"@XW;I_^O809_E`%!0X@H`
M``KL`9_E!!"-XHKY_^L`<%#B``"4Y4X```K>Z?_K$#"5Y0<@H.$`$)/E1^G_
MZP``F.78Z?_K`#"@XP00C>*0D9_EF'&?Y6$PP.6H`9_E>?G_ZP``4.,`0*#A
M[`\&Y1X```H'':#C@.G_ZQ$`4.,"```*`3"`X@$`4^-/``"*#-"-XO"/O>@!
M`%/CO___V@%`H.,``)CEO^G_ZPD0H.$&Z?_K]#\6Y0%`A.($`%/A]___RK7_
M_^H``)7EMNG_ZQ`PE.4`$)/E=^G_Z\/__^H!,-#E``!3XW3__PIR___J\`\7
MY=W\_^L``%#C[`\'Y3````H0()7EZ#"?Y0`@DN4($)+E`S`!X`$+4^,A```:
M$`"2Y?!/%N4$$*#A[>C_ZQ`PE>6\()_E`$"4Y0#`D^4(,)SE`B`#X`$+4N,`
M8*#A"P``&A`@G.4$$*#A!C"@X:@`G^4\Z?_KC^G_ZQ`@E>7P/Q;E``"2Y0`0
MD^6F^O_KKO__Z@``F.6'Z?_K$!"5Y0`@H.,",*#C`!"1Y?7H_^L`(*#AZ___
MZ@``F>5^Z?_K$!"5Y00@H.$",*#C`!"1Y>SH_^O6___J1`"?Y2+I_^OP'Q?E
M`#"@X00@H.$`$)'E,`"?Y1SI_^M0U@$`4/4```CW``!8]@$```0@`!#W```4
M]P``'/<```CU``#\]```1/<``"#W``!L]P``.$`MZ0!0H.&%^__K`##0Y0!`
MH.$``%/C!0``"@$@@.(O`%/C`D"@`0$PTN0``%/C^O__&B_\_^L``%#C.("]
M"```5>,X@+T(`##5Y0``4^,X@+T(!`"@X100G^5_Z/_K``!4X3B`O1@%`*#A
M.$"]Z+GY_^HL]@``$$`MZ21`G^4``)3E0>G_ZP`0X..[Z/_K``"4Y3WI_^L,
M$)_E`""@XQ!`O>@DZ?_J4-8!`$C;```,,)_E`S"/X```4^,`,),5D^C_ZI#B
M``#X12WI`'"@X4Q0G^5,8)_E!5"/X`9@C^`&8&7@`8"@X0*@H.%3Z/_K1F&P
MX?B%O0@$4$7B`$"@XP0PM>4'`*#A"!"@X0H@H.$!0(3B,_\OX08`5.'W__\:
M^(6]Z"#@```@X```'O\OX0A`+>D(@+WH`0`"`%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@`````.#W``#P]P``^/<```#X```(^```'/@`````
M``#8]P``^/0```````#0]0``U/4``,SW````]0``U/<```````"X]P``P/<`
M```````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`<&5R;'AS:2YC````26YT97)N86QS.CI005(Z.D)/3U0`
M````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!
M344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$52
M3#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T%21T,`
M````4$%27T%21U9?,```4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,
M7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/
M0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!365-414T``"4P,G@`````
M)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!P87)L`````"YP
M87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M
M<"TE=2TE=25S`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H``$%21U8`````&````'!E<FP`````,````%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M
M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP`````$Q$
M7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)
M0E)!4EE?4$%42````%-(3$E"7U!!5$@``",A+W5S<B]B:6XO<&5R;`IE=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?
M7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@
M;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L
M:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL
M93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U
M:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@
M=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@
M87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@
M(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R
M>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N
M<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D
M"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E
M(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S
M:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S
M92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN
M9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*
M("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@
M("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3
M549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@
M("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G
M"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E
M86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H
M;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T
M;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@
M8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T
M<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@
M?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?
M<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@
M86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6
M>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@
M("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK
M97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?
M05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#
M;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO
M(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA
M9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO
M9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I
M;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P
M96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?
M1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R
M96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN
M4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O
M<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I
M;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?
M;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*
M("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN
M*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF
M7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN
M960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2![
M"B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE
M*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@
M("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT
M("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@
M("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA
M;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@
M8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N
M86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@
M("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@
M;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@
M("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@
M)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L
M;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@
M("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@
M/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C
M86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@
M("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@
M("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@
M("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE
M9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@
M("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@
M("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O
M=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C
M?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B
M:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL
M96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M
M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@
M("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE
M<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S
M:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE
M879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U
M;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@
M;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I
M<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@
M("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@
M("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T
M871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]
M?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M
M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)5
M1WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X
M96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O
M7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN
M<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E
M<FEF>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@
M87,@(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!2
M3T=?05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@
M<&5R;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@
M87!P(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E
M;G9I<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@
M("`@)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@
M("`@96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY
M($!A9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@
M("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@
M("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@
M("`@979A;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P
M87)?87)G<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@
M("`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@
M("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`]
M(#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,
M)RD@>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R
M(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@
M("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!S:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@
M("`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@
M("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*
M?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*
M(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@
M("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL
M93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@
M*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P
M87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D
M<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@
M("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@
M("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@
M("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL
M97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P
M87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z
M("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@
M(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@
M("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R
M(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D
M("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&
M2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^
M("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@
M=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U
M8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]
M"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@
M(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I
M9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@
M("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@
M:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@
M("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\
M/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O
M0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE
M(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@
M("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y
M,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN
M+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@
M("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R
M87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G
M;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA
M<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@
M("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N
M9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD
M7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N
M.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@
M("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<
M421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N
M>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T
M<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@
M("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D
M8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@
M1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@
M("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)
M3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F
M*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@
M("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H
M92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S
M=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]
M"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W
M-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E
M<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O
M9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T
M(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@
M)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@
M("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@
M("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]
M"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO
M=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50
M871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y
M;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T
M<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,[
M"B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@
M("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,[
M"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@
M("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@
M("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV
M93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![
M(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@
M("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*
M(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R
M+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E
M='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M
M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$[
M"B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@
M*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U
M<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO
M="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@
M96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M
M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D[
M"B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L
M(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@
M("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@
M("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@
M(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@
M-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*
M("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@
M)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H
M)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@
M("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@
M:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE
M;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L
M("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E
M;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C
M;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE
M"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M
M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@
M("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@
M("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D[
M"B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@
M(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@
M("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2![
M"B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@
M("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@
M)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F
M:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<
M;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO
M;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE
M('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE
M("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*
M?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3$*"E]?
M14Y$7U\*`,A&_W\!`````````*";``!XFP````````$````!`````0````T"
M```!````&`(```$````B`@```0```'$"```!````I0,```$```#+`P``#```
M`"25```-````%/0``!D```#DTP$`&P````0````:````Z-,!`!P````$````
M]?[_;Y2!```%````0(P```8```!0A0``"@```$L%```+````$````!4`````
M`````P````C5`0`"````*`(``!0````1````%P```/R2```1````S)(``!(`
M```P````$P````@```#^__]O;)(``/___V\#````\/__;XR1````````````
M``````````````````````````````````````````````````````#PTP$`
M```````````PE0``,)4``#"5```PE0``,)4``#"5```PE0``,)4``#"5```P
ME0``,)4``#"5```PE0``,)4``#"5```PE0``,)4``#"5```PE0``,)4``#"5
M```PE0``,)4``#"5```PE0``,)4``#"5```PE0``,)4``#"5```PE0``,)4`
M`#"5```PE0``,)4``#"5```PE0``,)4``#"5```PE0``,)4``#"5```PE0``
M,)4``#"5```PE0``,)4``#"5```PE0``,)4``#"5```PE0``,)4``#"5```P
ME0``,)4``#"5```PE0``,)4``#"5```PE0``,)4``#"5```PE0``,)4``#"5
M```PE0``,)4``#"5``````````````````#_____*/@``$=#0SH@*%)A<W!B
M:6%N(#0N."XR+3$K<G!I,2D@-"XX+C(`1T-#.B`H1&5B:6%N(#0N-RXS+30K
M<G!I,2D@-"XW+C,`03````!A96%B:0`!)@````4V``8&"`$)`0H"$@03`10!
M%0$7`Q@!&0$:`AL#'`$B`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM
M=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L
M+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`
M+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````
M``````````````````````````````````````````````````L````!````
M`@```#2!```T`0``&0```````````````0`````````3````!P````(```!0
M@0``4`$``"````````````````0`````````(0````<````"````<($``'`!
M```D```````````````$`````````#0```#V__]O`@```)2!``"4`0``O`,`
M``4`````````!`````0````^````"P````(```!0A0``4`4``/`&```&````
M`0````0````0````1@````,````"````0(P``$`,``!+!0`````````````!
M`````````$X```#___]O`@```(R1``",$0``W@````4``````````@````(`
M``!;````_O__;P(```!LD@``;!(``&`````&`````P````0`````````:@``
M``D````"````S)(``,P2```P````!0`````````$````"````',````)````
M`@```/R2``#\$@``*`(```4````,````!`````@```!\`````0````8````D
ME0``)!4```P```````````````0`````````=P````$````&````,)4``#`5
M``!0`P`````````````$````!````((````!````!@```("8``"`&```E%L`
M````````````"`````````"(`````0````8````4]```%'0```@`````````
M``````0`````````C@````$````"````'/0``!QT``"\7P`````````````$
M`````````)8````!``!P@@```-A3`0#8TP``"`````T`````````!```````
M``"A`````0````(```#@4P$`X-,```0```````````````0`````````JP``
M``X````#````Y-,!`.33```$```````````````$`````````+<````/````
M`P```.C3`0#HTP``!```````````````!`````````##`````0````,```#L
MTP$`[-,```0```````````````0`````````R`````8````#````\-,!`/#3
M```8`0``!@`````````$````"````-$````!`````P````C5`0`(U0``)`$`
M````````````!`````0```#6`````0````,````LU@$`+-8``!``````````
M``````0`````````W`````@````#````0-8!`#S6```T$``````````````(
M`````````.$````!````,``````````\U@``1````````````````0````$`
M``#J`````P``<```````````@-8``#$```````````````$``````````0``
M``,``````````````+'6``#Z```````````````!``````````$````PE0``
M````````#``$````0)4```````````P``0```$25```````````,```D80`D
"9```
